==> pipewire-docs-1%3A0.3.31-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/files_dup.js <==
var files_dup =
[
    [ "alloc.h", "alloc_8h.html", "alloc_8h" ],
    [ "ansi.h", "ansi_8h.html", "ansi_8h" ],
    [ "array.h", "array_8h.html", "array_8h" ],
    [ "audio.h", "audio_8h.html", "audio_8h" ],
    [ "buffer/buffer.h", "buffer_2buffer_8h.html", "buffer_2buffer_8h" ],
    [ "debug/buffer.h", "debug_2buffer_8h.html", "debug_2buffer_8h" ],
    [ "buffers.c", "buffers_8c.html", "buffers_8c" ],
    [ "buffers.h", "buffers_8h.html", "buffers_8h" ],
    [ "builder.h", "builder_8h.html", "builder_8h" ],
    [ "chroma.h", "chroma_8h.html", "chroma_8h" ],
    [ "client.h", "client_8h.html", "client_8h" ],
    [ "color.h", "color_8h.html", "color_8h" ],
    [ "node/command.h", "node_2command_8h.html", "node_2command_8h" ],
    [ "pod/command.h", "pod_2command_8h.html", "pod_2command_8h" ],
    [ "compare.h", "compare_8h.html", "compare_8h" ],
    [ "conf.c", "conf_8c.html", "conf_8c" ],
    [ "conf.h", "conf_8h.html", "conf_8h" ],
    [ "context.c", "context_8c.html", "context_8c" ],
    [ "context.h", "context_8h.html", "context_8h" ],
    [ "control.c", "control_8c.html", "control_8c" ],
    [ "pipewire/src/pipewire/control.h", "pipewire_2src_2pipewire_2control_8h.html", "pipewire_2src_2pipewire_2control_8h" ],
    [ "build/doc/spa/control/control.h", "build_2doc_2spa_2control_2control_8h.html", "build_2doc_2spa_2control_2control_8h" ],
    [ "core.c", "core_8c.html", "core_8c" ],
    [ "core.h", "core_8h.html", "core_8h" ],
    [ "cpu.h", "cpu_8h.html", "cpu_8h" ],
    [ "data-loop.c", "data-loop_8c.html", "data-loop_8c" ],
    [ "data-loop.h", "data-loop_8h.html", "data-loop_8h" ],
    [ "dbus.h", "dbus_8h.html", "dbus_8h" ],
    [ "defs.h", "defs_8h.html", "defs_8h" ],
    [ "pipewire/src/pipewire/device.h", "pipewire_2src_2pipewire_2device_8h.html", "pipewire_2src_2pipewire_2device_8h" ],
    [ "build/doc/spa/monitor/device.h", "build_2doc_2spa_2monitor_2device_8h.html", "build_2doc_2spa_2monitor_2device_8h" ],
    [ "debug/dict.h", "debug_2dict_8h.html", "debug_2dict_8h" ],
    [ "utils/dict.h", "utils_2dict_8h.html", "utils_2dict_8h" ],
    [ "encoded.h", "encoded_8h.html", "encoded_8h" ],
    [ "monitor/event.h", "monitor_2event_8h.html", "monitor_2event_8h" ],
    [ "node/event.h", "node_2event_8h.html", "node_2event_8h" ],
    [ "pod/event.h", "pod_2event_8h.html", "pod_2event_8h" ],
    [ "factory.h", "factory_8h.html", "factory_8h" ],
    [ "filter.c", "filter_8c.html", "filter_8c" ],
    [ "pipewire/src/pipewire/filter.h", "pipewire_2src_2pipewire_2filter_8h.html", "pipewire_2src_2pipewire_2filter_8h" ],
    [ "build/doc/spa/pod/filter.h", "build_2doc_2spa_2pod_2filter_8h.html", "build_2doc_2spa_2pod_2filter_8h" ],
    [ "audio/format-utils.h", "audio_2format-utils_8h.html", "audio_2format-utils_8h" ],
    [ "format-utils.h", "format-utils_8h.html", "format-utils_8h" ],
    [ "video/format-utils.h", "video_2format-utils_8h.html", "video_2format-utils_8h" ],
    [ "debug/format.h", "debug_2format_8h.html", "debug_2format_8h" ],
    [ "param/audio/format.h", "param_2audio_2format_8h.html", null ],
    [ "param/format.h", "param_2format_8h.html", "param_2format_8h" ],
    [ "param/video/format.h", "param_2video_2format_8h.html", null ],
    [ "global.c", "global_8c.html", "global_8c" ],
    [ "global.h", "global_8h.html", "global_8h" ],
    [ "graph.h", "graph_8h.html", "graph_8h" ],
    [ "hook.h", "hook_8h.html", "hook_8h" ],
    [ "pipewire/src/pipewire/i18n.h", "pipewire_2src_2pipewire_2i18n_8h.html", "pipewire_2src_2pipewire_2i18n_8h" ],
    [ "build/doc/spa/support/i18n.h", "build_2doc_2spa_2support_2i18n_8h.html", "build_2doc_2spa_2support_2i18n_8h" ],
    [ "impl-client.c", "impl-client_8c.html", "impl-client_8c" ],
    [ "impl-client.h", "impl-client_8h.html", "impl-client_8h" ],
    [ "impl-core.c", "impl-core_8c.html", "impl-core_8c" ],
    [ "impl-core.h", "impl-core_8h.html", "impl-core_8h" ],
    [ "impl-device.c", "impl-device_8c.html", "impl-device_8c" ],
    [ "impl-device.h", "impl-device_8h.html", "impl-device_8h" ],
    [ "impl-factory.c", "impl-factory_8c.html", "impl-factory_8c" ],
    [ "impl-factory.h", "impl-factory_8h.html", "impl-factory_8h" ],
    [ "impl-link.c", "impl-link_8c.html", "impl-link_8c" ],
    [ "impl-link.h", "impl-link_8h.html", "impl-link_8h" ],
    [ "impl-metadata.c", "impl-metadata_8c.html", "impl-metadata_8c" ],
    [ "impl-metadata.h", "impl-metadata_8h.html", "impl-metadata_8h" ],
    [ "impl-module.c", "impl-module_8c.html", "impl-module_8c" ],
    [ "impl-module.h", "impl-module_8h.html", "impl-module_8h" ],
    [ "impl-node.c", "impl-node_8c.html", "impl-node_8c" ],
    [ "impl-node.h", "impl-node_8h.html", "impl-node_8h" ],
    [ "impl-port.c", "impl-port_8c.html", "impl-port_8c" ],
    [ "impl-port.h", "impl-port_8h.html", "impl-port_8h" ],
    [ "impl.h", "impl_8h.html", null ],
    [ "introspect.c", "introspect_8c.html", "introspect_8c" ],
    [ "io.h", "io_8h.html", "io_8h" ],
    [ "iter.h", "iter_8h.html", "iter_8h" ],
    [ "json.h", "json_8h.html", "json_8h" ],
    [ "pipewire/src/pipewire/keys.h", "pipewire_2src_2pipewire_2keys_8h.html", "pipewire_2src_2pipewire_2keys_8h" ],
    [ "build/doc/spa/node/keys.h", "build_2doc_2spa_2node_2keys_8h.html", "build_2doc_2spa_2node_2keys_8h" ],
    [ "build/doc/spa/utils/keys.h", "build_2doc_2spa_2utils_2keys_8h.html", "build_2doc_2spa_2utils_2keys_8h" ],
    [ "latency-utils.h", "latency-utils_8h.html", "latency-utils_8h" ],
    [ "layout.h", "layout_8h.html", "layout_8h" ],
    [ "link.h", "link_8h.html", "link_8h" ],
    [ "list.h", "list_8h.html", "list_8h" ],
    [ "log-impl.h", "log-impl_8h.html", "log-impl_8h" ],
    [ "log.c", "log_8c.html", "log_8c" ],
    [ "pipewire/src/pipewire/log.h", "pipewire_2src_2pipewire_2log_8h.html", "pipewire_2src_2pipewire_2log_8h" ],
    [ "build/doc/spa/support/log.h", "build_2doc_2spa_2support_2log_8h.html", "build_2doc_2spa_2support_2log_8h" ],
    [ "loop.c", "loop_8c.html", "loop_8c" ],
    [ "pipewire/src/pipewire/loop.h", "pipewire_2src_2pipewire_2loop_8h.html", "pipewire_2src_2pipewire_2loop_8h" ],
    [ "build/doc/spa/support/loop.h", "build_2doc_2spa_2support_2loop_8h.html", "build_2doc_2spa_2support_2loop_8h" ],
    [ "main-loop.c", "main-loop_8c.html", "main-loop_8c" ],
    [ "main-loop.h", "main-loop_8h.html", "main-loop_8h" ],
    [ "map.h", "map_8h.html", "map_8h" ],
    [ "mem.c", "mem_8c.html", "mem_8c" ],
    [ "pipewire/src/pipewire/mem.h", "pipewire_2src_2pipewire_2mem_8h.html", "pipewire_2src_2pipewire_2mem_8h" ],
    [ "build/doc/spa/debug/mem.h", "build_2doc_2spa_2debug_2mem_8h.html", "build_2doc_2spa_2debug_2mem_8h" ],
    [ "meta.h", "meta_8h.html", "meta_8h" ],
    [ "module-access.c", "module-access_8c.html", "module-access_8c" ],
    [ "module-adapter.c", "module-adapter_8c.html", "module-adapter_8c" ],
    [ "module-client-device.c", "module-client-device_8c.html", "module-client-device_8c" ],
    [ "module-client-node.c", "module-client-node_8c.html", "module-client-node_8c" ],
    [ "module-echo-cancel.c", "module-echo-cancel_8c.html", "module-echo-cancel_8c" ],
    [ "module-example-sink.c", "module-example-sink_8c.html", "module-example-sink_8c" ],
    [ "module-example-source.c", "module-example-source_8c.html", "module-example-source_8c" ],
    [ "module-filter-chain.c", "module-filter-chain_8c.html", "module-filter-chain_8c" ],
    [ "module-link-factory.c", "module-link-factory_8c.html", "module-link-factory_8c" ],
    [ "module-loopback.c", "module-loopback_8c.html", "module-loopback_8c" ],
    [ "module-metadata.c", "module-metadata_8c.html", "module-metadata_8c" ],
    [ "module-portal.c", "module-portal_8c.html", "module-portal_8c" ],
    [ "module-profiler.c", "module-profiler_8c.html", "module-profiler_8c" ],
    [ "module-protocol-native.c", "module-protocol-native_8c.html", "module-protocol-native_8c" ],
    [ "module-protocol-pulse.c", "module-protocol-pulse_8c.html", "module-protocol-pulse_8c" ],
    [ "module-protocol-simple.c", "module-protocol-simple_8c.html", "module-protocol-simple_8c" ],
    [ "module-pulse-tunnel.c", "module-pulse-tunnel_8c.html", "module-pulse-tunnel_8c" ],
    [ "module-roc-sink.c", "module-roc-sink_8c.html", "module-roc-sink_8c" ],
    [ "module-roc-source.c", "module-roc-source_8c.html", "module-roc-source_8c" ],
    [ "module-rt.c", "module-rt_8c.html", "module-rt_8c" ],
    [ "module-rtkit.c", "module-rtkit_8c.html", "module-rtkit_8c" ],
    [ "module-session-manager.c", "module-session-manager_8c.html", "module-session-manager_8c" ],
    [ "module-zeroconf-discover.c", "module-zeroconf-discover_8c.html", "module-zeroconf-discover_8c" ],
    [ "module.h", "module_8h.html", "module_8h" ],
    [ "multiview.h", "multiview_8h.html", "multiview_8h" ],
    [ "names.h", "names_8h.html", "names_8h" ],
    [ "pipewire/src/pipewire/node.h", "pipewire_2src_2pipewire_2node_8h.html", "pipewire_2src_2pipewire_2node_8h" ],
    [ "build/doc/spa/debug/node.h", "build_2doc_2spa_2debug_2node_8h.html", "build_2doc_2spa_2debug_2node_8h" ],
    [ "build/doc/spa/node/node.h", "build_2doc_2spa_2node_2node_8h.html", "build_2doc_2spa_2node_2node_8h" ],
    [ "param.h", "param_8h.html", "param_8h" ],
    [ "parser.h", "parser_8h.html", "parser_8h" ],
    [ "permission.h", "permission_8h.html", "permission_8h" ],
    [ "pipewire.c", "pipewire_8c.html", "pipewire_8c" ],
    [ "pipewire.h", "pipewire_8h.html", "pipewire_8h" ],
    [ "plugin.h", "plugin_8h.html", "plugin_8h" ],
    [ "debug/pod.h", "debug_2pod_8h.html", "debug_2pod_8h" ],
    [ "pod/pod.h", "pod_2pod_8h.html", "pod_2pod_8h" ],
    [ "port.h", "port_8h.html", "port_8h" ],
    [ "profiler.h", "profiler_8h.html", "profiler_8h" ],
    [ "properties.c", "properties_8c.html", "properties_8c" ],
    [ "properties.h", "properties_8h.html", "properties_8h" ],
    [ "props.h", "props_8h.html", "props_8h" ],
    [ "protocol.c", "protocol_8c.html", "protocol_8c" ],
    [ "protocol.h", "protocol_8h.html", "protocol_8h" ],
    [ "proxy.c", "proxy_8c.html", "proxy_8c" ],
    [ "proxy.h", "proxy_8h.html", "proxy_8h" ],
    [ "pwtest.h", "pwtest_8h.html", "pwtest_8h" ],
    [ "audio/raw.h", "audio_2raw_8h.html", "audio_2raw_8h" ],
    [ "video/raw.h", "video_2raw_8h.html", "video_2raw_8h" ],
    [ "resource.c", "resource_8c.html", "resource_8c" ],
    [ "resource.h", "resource_8h.html", "resource_8h" ],
    [ "result.h", "result_8h.html", "result_8h" ],
    [ "ringbuffer.h", "ringbuffer_8h.html", "ringbuffer_8h" ],
    [ "settings.c", "settings_8c.html", "settings_8c" ],
    [ "stream.c", "stream_8c.html", "stream_8c" ],
    [ "stream.h", "stream_8h.html", "stream_8h" ],
    [ "string.h", "string_8h.html", "string_8h" ],
    [ "system.h", "system_8h.html", "system_8h" ],
    [ "thread-loop.c", "thread-loop_8c.html", "thread-loop_8c" ],
    [ "thread-loop.h", "thread-loop_8h.html", "thread-loop_8h" ],
    [ "buffer/type-info.h", "buffer_2type-info_8h.html", "buffer_2type-info_8h" ],
    [ "control/type-info.h", "control_2type-info_8h.html", "control_2type-info_8h" ],
    [ "monitor/type-info.h", "monitor_2type-info_8h.html", "monitor_2type-info_8h" ],
    [ "node/type-info.h", "node_2type-info_8h.html", "node_2type-info_8h" ],
    [ "param/audio/type-info.h", "param_2audio_2type-info_8h.html", "param_2audio_2type-info_8h" ],
    [ "param/bluetooth/type-info.h", "param_2bluetooth_2type-info_8h.html", "param_2bluetooth_2type-info_8h" ],
    [ "param/type-info.h", "param_2type-info_8h.html", "param_2type-info_8h" ],
    [ "param/video/type-info.h", "param_2video_2type-info_8h.html", "param_2video_2type-info_8h" ],
    [ "utils/type-info.h", "utils_2type-info_8h.html", "utils_2type-info_8h" ],
    [ "pipewire/src/pipewire/type.h", "pipewire_2src_2pipewire_2type_8h.html", "pipewire_2src_2pipewire_2type_8h" ],
    [ "build/doc/spa/utils/type.h", "build_2doc_2spa_2utils_2type_8h.html", "build_2doc_2spa_2utils_2type_8h" ],
    [ "types.h", "types_8h.html", "types_8h" ],
    [ "utils.c", "utils_8c.html", "utils_8c" ],
    [ "pipewire/src/pipewire/utils.h", "pipewire_2src_2pipewire_2utils_8h.html", "pipewire_2src_2pipewire_2utils_8h" ],
    [ "build/doc/spa/monitor/utils.h", "build_2doc_2spa_2monitor_2utils_8h.html", "build_2doc_2spa_2monitor_2utils_8h" ],
    [ "build/doc/spa/node/utils.h", "build_2doc_2spa_2node_2utils_8h.html", "build_2doc_2spa_2node_2utils_8h" ],
    [ "vararg.h", "vararg_8h.html", "vararg_8h" ],
    [ "work-queue.c", "work-queue_8c.html", "work-queue_8c" ],
    [ "work-queue.h", "work-queue_8h.html", "work-queue_8h" ]
];

==> pipewire-docs-1%3A0.3.32-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/files_dup.js <==
var files_dup =
[
    [ "alloc.h", "alloc_8h.html", "alloc_8h" ],
    [ "ansi.h", "ansi_8h.html", "ansi_8h" ],
    [ "array.h", "array_8h.html", "array_8h" ],
    [ "audio.h", "audio_8h.html", "audio_8h" ],
    [ "buffer/buffer.h", "buffer_2buffer_8h.html", "buffer_2buffer_8h" ],
    [ "debug/buffer.h", "debug_2buffer_8h.html", "debug_2buffer_8h" ],
    [ "buffers.c", "buffers_8c.html", "buffers_8c" ],
    [ "buffers.h", "buffers_8h.html", "buffers_8h" ],
    [ "builder.h", "builder_8h.html", "builder_8h" ],
    [ "chroma.h", "chroma_8h.html", "chroma_8h" ],
    [ "client.h", "client_8h.html", "client_8h" ],
    [ "color.h", "color_8h.html", "color_8h" ],
    [ "node/command.h", "node_2command_8h.html", "node_2command_8h" ],
    [ "pod/command.h", "pod_2command_8h.html", "pod_2command_8h" ],
    [ "compare.h", "compare_8h.html", "compare_8h" ],
    [ "conf.c", "conf_8c.html", "conf_8c" ],
    [ "conf.h", "conf_8h.html", "conf_8h" ],
    [ "context.c", "context_8c.html", "context_8c" ],
    [ "context.h", "context_8h.html", "context_8h" ],
    [ "control.c", "control_8c.html", "control_8c" ],
    [ "pipewire/src/pipewire/control.h", "pipewire_2src_2pipewire_2control_8h.html", "pipewire_2src_2pipewire_2control_8h" ],
    [ "build/doc/spa/control/control.h", "build_2doc_2spa_2control_2control_8h.html", "build_2doc_2spa_2control_2control_8h" ],
    [ "core.c", "core_8c.html", "core_8c" ],
    [ "core.h", "core_8h.html", "core_8h" ],
    [ "cpu.h", "cpu_8h.html", "cpu_8h" ],
    [ "data-loop.c", "data-loop_8c.html", "data-loop_8c" ],
    [ "data-loop.h", "data-loop_8h.html", "data-loop_8h" ],
    [ "dbus.h", "dbus_8h.html", "dbus_8h" ],
    [ "defs.h", "defs_8h.html", "defs_8h" ],
    [ "pipewire/src/pipewire/device.h", "pipewire_2src_2pipewire_2device_8h.html", "pipewire_2src_2pipewire_2device_8h" ],
    [ "build/doc/spa/monitor/device.h", "build_2doc_2spa_2monitor_2device_8h.html", "build_2doc_2spa_2monitor_2device_8h" ],
    [ "debug/dict.h", "debug_2dict_8h.html", "debug_2dict_8h" ],
    [ "utils/dict.h", "utils_2dict_8h.html", "utils_2dict_8h" ],
    [ "encoded.h", "encoded_8h.html", "encoded_8h" ],
    [ "monitor/event.h", "monitor_2event_8h.html", "monitor_2event_8h" ],
    [ "node/event.h", "node_2event_8h.html", "node_2event_8h" ],
    [ "pod/event.h", "pod_2event_8h.html", "pod_2event_8h" ],
    [ "factory.h", "factory_8h.html", "factory_8h" ],
    [ "filter.c", "filter_8c.html", "filter_8c" ],
    [ "pipewire/src/pipewire/filter.h", "pipewire_2src_2pipewire_2filter_8h.html", "pipewire_2src_2pipewire_2filter_8h" ],
    [ "build/doc/spa/pod/filter.h", "build_2doc_2spa_2pod_2filter_8h.html", "build_2doc_2spa_2pod_2filter_8h" ],
    [ "audio/format-utils.h", "audio_2format-utils_8h.html", "audio_2format-utils_8h" ],
    [ "format-utils.h", "format-utils_8h.html", "format-utils_8h" ],
    [ "video/format-utils.h", "video_2format-utils_8h.html", "video_2format-utils_8h" ],
    [ "debug/format.h", "debug_2format_8h.html", "debug_2format_8h" ],
    [ "param/audio/format.h", "param_2audio_2format_8h.html", null ],
    [ "param/format.h", "param_2format_8h.html", "param_2format_8h" ],
    [ "param/video/format.h", "param_2video_2format_8h.html", null ],
    [ "global.c", "global_8c.html", "global_8c" ],
    [ "global.h", "global_8h.html", "global_8h" ],
    [ "graph.h", "graph_8h.html", "graph_8h" ],
    [ "hook.h", "hook_8h.html", "hook_8h" ],
    [ "pipewire/src/pipewire/i18n.h", "pipewire_2src_2pipewire_2i18n_8h.html", "pipewire_2src_2pipewire_2i18n_8h" ],
    [ "build/doc/spa/support/i18n.h", "build_2doc_2spa_2support_2i18n_8h.html", "build_2doc_2spa_2support_2i18n_8h" ],
    [ "impl-client.c", "impl-client_8c.html", "impl-client_8c" ],
    [ "impl-client.h", "impl-client_8h.html", "impl-client_8h" ],
    [ "impl-core.c", "impl-core_8c.html", "impl-core_8c" ],
    [ "impl-core.h", "impl-core_8h.html", "impl-core_8h" ],
    [ "impl-device.c", "impl-device_8c.html", "impl-device_8c" ],
    [ "impl-device.h", "impl-device_8h.html", "impl-device_8h" ],
    [ "impl-factory.c", "impl-factory_8c.html", "impl-factory_8c" ],
    [ "impl-factory.h", "impl-factory_8h.html", "impl-factory_8h" ],
    [ "impl-link.c", "impl-link_8c.html", "impl-link_8c" ],
    [ "impl-link.h", "impl-link_8h.html", "impl-link_8h" ],
    [ "impl-metadata.c", "impl-metadata_8c.html", "impl-metadata_8c" ],
    [ "impl-metadata.h", "impl-metadata_8h.html", "impl-metadata_8h" ],
    [ "impl-module.c", "impl-module_8c.html", "impl-module_8c" ],
    [ "impl-module.h", "impl-module_8h.html", "impl-module_8h" ],
    [ "impl-node.c", "impl-node_8c.html", "impl-node_8c" ],
    [ "impl-node.h", "impl-node_8h.html", "impl-node_8h" ],
    [ "impl-port.c", "impl-port_8c.html", "impl-port_8c" ],
    [ "impl-port.h", "impl-port_8h.html", "impl-port_8h" ],
    [ "impl.h", "impl_8h.html", null ],
    [ "introspect.c", "introspect_8c.html", "introspect_8c" ],
    [ "io.h", "io_8h.html", "io_8h" ],
    [ "iter.h", "iter_8h.html", "iter_8h" ],
    [ "json.h", "json_8h.html", "json_8h" ],
    [ "pipewire/src/pipewire/keys.h", "pipewire_2src_2pipewire_2keys_8h.html", "pipewire_2src_2pipewire_2keys_8h" ],
    [ "build/doc/spa/node/keys.h", "build_2doc_2spa_2node_2keys_8h.html", "build_2doc_2spa_2node_2keys_8h" ],
    [ "build/doc/spa/utils/keys.h", "build_2doc_2spa_2utils_2keys_8h.html", "build_2doc_2spa_2utils_2keys_8h" ],
    [ "latency-utils.h", "latency-utils_8h.html", "latency-utils_8h" ],
    [ "layout.h", "layout_8h.html", "layout_8h" ],
    [ "link.h", "link_8h.html", "link_8h" ],
    [ "list.h", "list_8h.html", "list_8h" ],
    [ "log-impl.h", "log-impl_8h.html", "log-impl_8h" ],
    [ "log.c", "log_8c.html", "log_8c" ],
    [ "pipewire/src/pipewire/log.h", "pipewire_2src_2pipewire_2log_8h.html", "pipewire_2src_2pipewire_2log_8h" ],
    [ "build/doc/spa/support/log.h", "build_2doc_2spa_2support_2log_8h.html", "build_2doc_2spa_2support_2log_8h" ],
    [ "loop.c", "loop_8c.html", "loop_8c" ],
    [ "pipewire/src/pipewire/loop.h", "pipewire_2src_2pipewire_2loop_8h.html", "pipewire_2src_2pipewire_2loop_8h" ],
    [ "build/doc/spa/support/loop.h", "build_2doc_2spa_2support_2loop_8h.html", "build_2doc_2spa_2support_2loop_8h" ],
    [ "main-loop.c", "main-loop_8c.html", "main-loop_8c" ],
    [ "main-loop.h", "main-loop_8h.html", "main-loop_8h" ],
    [ "map.h", "map_8h.html", "map_8h" ],
    [ "mem.c", "mem_8c.html", "mem_8c" ],
    [ "pipewire/src/pipewire/mem.h", "pipewire_2src_2pipewire_2mem_8h.html", "pipewire_2src_2pipewire_2mem_8h" ],
    [ "build/doc/spa/debug/mem.h", "build_2doc_2spa_2debug_2mem_8h.html", "build_2doc_2spa_2debug_2mem_8h" ],
    [ "meta.h", "meta_8h.html", "meta_8h" ],
    [ "module-access.c", "module-access_8c.html", "module-access_8c" ],
    [ "module-adapter.c", "module-adapter_8c.html", "module-adapter_8c" ],
    [ "module-client-device.c", "module-client-device_8c.html", "module-client-device_8c" ],
    [ "module-client-node.c", "module-client-node_8c.html", "module-client-node_8c" ],
    [ "module-echo-cancel.c", "module-echo-cancel_8c.html", "module-echo-cancel_8c" ],
    [ "module-example-sink.c", "module-example-sink_8c.html", "module-example-sink_8c" ],
    [ "module-example-source.c", "module-example-source_8c.html", "module-example-source_8c" ],
    [ "module-filter-chain.c", "module-filter-chain_8c.html", "module-filter-chain_8c" ],
    [ "module-link-factory.c", "module-link-factory_8c.html", "module-link-factory_8c" ],
    [ "module-loopback.c", "module-loopback_8c.html", "module-loopback_8c" ],
    [ "module-metadata.c", "module-metadata_8c.html", "module-metadata_8c" ],
    [ "module-portal.c", "module-portal_8c.html", "module-portal_8c" ],
    [ "module-profiler.c", "module-profiler_8c.html", "module-profiler_8c" ],
    [ "module-protocol-native.c", "module-protocol-native_8c.html", "module-protocol-native_8c" ],
    [ "module-protocol-pulse.c", "module-protocol-pulse_8c.html", "module-protocol-pulse_8c" ],
    [ "module-protocol-simple.c", "module-protocol-simple_8c.html", "module-protocol-simple_8c" ],
    [ "module-pulse-tunnel.c", "module-pulse-tunnel_8c.html", "module-pulse-tunnel_8c" ],
    [ "module-roc-sink.c", "module-roc-sink_8c.html", "module-roc-sink_8c" ],
    [ "module-roc-source.c", "module-roc-source_8c.html", "module-roc-source_8c" ],
    [ "module-rt.c", "module-rt_8c.html", "module-rt_8c" ],
    [ "module-rtkit.c", "module-rtkit_8c.html", "module-rtkit_8c" ],
    [ "module-session-manager.c", "module-session-manager_8c.html", "module-session-manager_8c" ],
    [ "module-zeroconf-discover.c", "module-zeroconf-discover_8c.html", "module-zeroconf-discover_8c" ],
    [ "module.h", "module_8h.html", "module_8h" ],
    [ "multiview.h", "multiview_8h.html", "multiview_8h" ],
    [ "names.h", "names_8h.html", "names_8h" ],
    [ "pipewire/src/pipewire/node.h", "pipewire_2src_2pipewire_2node_8h.html", "pipewire_2src_2pipewire_2node_8h" ],
    [ "build/doc/spa/debug/node.h", "build_2doc_2spa_2debug_2node_8h.html", "build_2doc_2spa_2debug_2node_8h" ],
    [ "build/doc/spa/node/node.h", "build_2doc_2spa_2node_2node_8h.html", "build_2doc_2spa_2node_2node_8h" ],
    [ "param.h", "param_8h.html", "param_8h" ],
    [ "parser.h", "parser_8h.html", "parser_8h" ],
    [ "permission.h", "permission_8h.html", "permission_8h" ],
    [ "pipewire.c", "pipewire_8c.html", "pipewire_8c" ],
    [ "pipewire.h", "pipewire_8h.html", "pipewire_8h" ],
    [ "plugin.h", "plugin_8h.html", "plugin_8h" ],
    [ "debug/pod.h", "debug_2pod_8h.html", "debug_2pod_8h" ],
    [ "pod/pod.h", "pod_2pod_8h.html", "pod_2pod_8h" ],
    [ "port.h", "port_8h.html", "port_8h" ],
    [ "profiler.h", "profiler_8h.html", "profiler_8h" ],
    [ "properties.c", "properties_8c.html", "properties_8c" ],
    [ "properties.h", "properties_8h.html", "properties_8h" ],
    [ "props.h", "props_8h.html", "props_8h" ],
    [ "protocol.c", "protocol_8c.html", "protocol_8c" ],
    [ "protocol.h", "protocol_8h.html", "protocol_8h" ],
    [ "proxy.c", "proxy_8c.html", "proxy_8c" ],
    [ "proxy.h", "proxy_8h.html", "proxy_8h" ],
    [ "pwtest.h", "pwtest_8h.html", "pwtest_8h" ],
    [ "audio/raw.h", "audio_2raw_8h.html", "audio_2raw_8h" ],
    [ "video/raw.h", "video_2raw_8h.html", "video_2raw_8h" ],
    [ "resource.c", "resource_8c.html", "resource_8c" ],
    [ "resource.h", "resource_8h.html", "resource_8h" ],
    [ "result.h", "result_8h.html", "result_8h" ],
    [ "ringbuffer.h", "ringbuffer_8h.html", "ringbuffer_8h" ],
    [ "settings.c", "settings_8c.html", "settings_8c" ],
    [ "stream.c", "stream_8c.html", "stream_8c" ],
    [ "stream.h", "stream_8h.html", "stream_8h" ],
    [ "string.h", "string_8h.html", "string_8h" ],
    [ "system.h", "system_8h.html", "system_8h" ],
    [ "thread-loop.c", "thread-loop_8c.html", "thread-loop_8c" ],
    [ "thread-loop.h", "thread-loop_8h.html", "thread-loop_8h" ],
    [ "thread.c", "thread_8c.html", "thread_8c" ],
    [ "pipewire/src/pipewire/thread.h", "pipewire_2src_2pipewire_2thread_8h.html", "pipewire_2src_2pipewire_2thread_8h" ],
    [ "build/doc/spa/support/thread.h", "build_2doc_2spa_2support_2thread_8h.html", "build_2doc_2spa_2support_2thread_8h" ],
    [ "buffer/type-info.h", "buffer_2type-info_8h.html", "buffer_2type-info_8h" ],
    [ "control/type-info.h", "control_2type-info_8h.html", "control_2type-info_8h" ],
    [ "monitor/type-info.h", "monitor_2type-info_8h.html", "monitor_2type-info_8h" ],
    [ "node/type-info.h", "node_2type-info_8h.html", "node_2type-info_8h" ],
    [ "param/audio/type-info.h", "param_2audio_2type-info_8h.html", "param_2audio_2type-info_8h" ],
    [ "param/bluetooth/type-info.h", "param_2bluetooth_2type-info_8h.html", "param_2bluetooth_2type-info_8h" ],
    [ "param/type-info.h", "param_2type-info_8h.html", "param_2type-info_8h" ],
    [ "param/video/type-info.h", "param_2video_2type-info_8h.html", "param_2video_2type-info_8h" ],
    [ "utils/type-info.h", "utils_2type-info_8h.html", "utils_2type-info_8h" ],
    [ "pipewire/src/pipewire/type.h", "pipewire_2src_2pipewire_2type_8h.html", "pipewire_2src_2pipewire_2type_8h" ],
    [ "build/doc/spa/utils/type.h", "build_2doc_2spa_2utils_2type_8h.html", "build_2doc_2spa_2utils_2type_8h" ],
    [ "types.h", "types_8h.html", "types_8h" ],
    [ "utils.c", "utils_8c.html", "utils_8c" ],
    [ "pipewire/src/pipewire/utils.h", "pipewire_2src_2pipewire_2utils_8h.html", "pipewire_2src_2pipewire_2utils_8h" ],
    [ "build/doc/spa/monitor/utils.h", "build_2doc_2spa_2monitor_2utils_8h.html", "build_2doc_2spa_2monitor_2utils_8h" ],
    [ "build/doc/spa/node/utils.h", "build_2doc_2spa_2node_2utils_8h.html", "build_2doc_2spa_2node_2utils_8h" ],
    [ "vararg.h", "vararg_8h.html", "vararg_8h" ],
    [ "work-queue.c", "work-queue_8c.html", "work-queue_8c" ],
    [ "work-queue.h", "work-queue_8h.html", "work-queue_8h" ]
];
